@@ -140,10 +140,3 @@ bool page_is_visible(zathura_document_t* document, unsigned int page_number) {
   return (fabs(pos_x - page_x) < 0.5 * (double)(view_width + cell_width) / (double)doc_width &&
           fabs(pos_y - page_y) < 0.5 * (double)(view_height + cell_height) / (double)doc_height);
 }
-
-void zathura_adjustment_set_value(GtkAdjustment* adjustment, gdouble value) {
-  const gdouble lower        = gtk_adjustment_get_lower(adjustment);
-  const gdouble upper_m_size = gtk_adjustment_get_upper(adjustment) - gtk_adjustment_get_page_size(adjustment);
-
-  gtk_adjustment_set_value(adjustment, MAX(lower, MIN(upper_m_size, value)));
-}
